@@ -4,14 +4,14 @@
 
 
 char *
-get_config_string(const char *path)
+get_config_string(const char * /*path*/)
 {
     return NULL;
 }
 
 
 void
-set_config_string(const char *path, const char *value)
+set_config_string(const char * /*path*/, const char * /*value*/)
 {
 }
 
