@@ -39,11 +39,9 @@ initDictPointers()
 void
 set_window_icon_to_default(GtkWidget *window)
 {
-    GdkPixbuf *icon = gdk_pixbuf_new_from_file(
-                                PIXMAPDIR "/" PACKAGE ".png", NULL);
+    GdkPixbuf *icon = gdk_pixbuf_new_from_file(PIXMAPDIR "/" PACKAGE ".svg", NULL);
     if (icon == NULL)
-        g_warning("gdk_pixbuf_new_from_file() failed on "
-                                PIXMAPDIR "/" PACKAGE ".png");
+        g_warning("gdk_pixbuf_new_from_file() failed on " PIXMAPDIR "/" PACKAGE ".svg");
     else
         gtk_window_set_icon(GTK_WINDOW(window), icon);
 }
