@@ -2,7 +2,7 @@
     FrenchVerbDictionary.cpp - Dictionary of verbs and conjugation templates
 
     verbiste - French conjugation system
-    Copyright (C) 2003-2010 Pierre Sarrazin <http://sarrazip.com/>
+    Copyright (C) 2003-2015 Pierre Sarrazin <http://sarrazip.com/>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -54,36 +54,11 @@ private:
 };
 
 
-class AutoString
-{
-public:
-    AutoString(xmlChar *s) : str(s) {}
-    ~AutoString() { if (str != NULL) xmlFree(str); }
-    xmlChar *get() const { return str; }
-    bool operator ! () const { return str == NULL; }
-    size_t length() const { return str == NULL ? 0 : strlen((char *) str); }
-private:
-    xmlChar *str;
-
-    // Forbidden operations:
-    AutoString(const AutoString &);
-    AutoString &operator = (const AutoString &);
-};
-
-
-inline
-const xmlChar *
-XMLCHAR(const char *s)
-{
-    return (const xmlChar *) s;
-}
-
-
 inline
 int
 equal(const xmlChar *a, const char *b)
 {
-    return xmlStrcmp(a, XMLCHAR(b)) == 0;
+    return xmlStrcmp(a, (const xmlChar *) b) == 0;
 }
 
 
@@ -95,54 +70,6 @@ different(const xmlChar *a, const char *b)
 }
 
 
-inline
-xmlChar *
-getProp(xmlNodePtr node, const char *propName)
-{
-    return xmlGetProp(node, XMLCHAR(propName));
-}
-
-
-inline
-xmlChar *
-getString(xmlDocPtr doc, xmlNodePtr node)
-{
-    return xmlNodeListGetString(doc, node, 1);
-}
-
-
-inline
-string
-operator + (const AutoString &a, const string &b)
-{
-    return (char *) a.get() + b;
-}
-
-
-inline
-string
-operator + (const string &a, const AutoString &b)
-{
-    return a + (char *) b.get();
-}
-
-
-inline
-Mode
-convertModeName(const xmlChar *modeName)
-{
-    return FrenchVerbDictionary::convertModeName((char *) modeName);
-}
-
-
-inline
-Tense
-convertTenseName(const xmlChar *tenseName)
-{
-    return FrenchVerbDictionary::convertTenseName((char *) tenseName);
-}
-
-
 // Latin-1 to ASCII conversion table (codes 0xC0 to 0xFF).
 // Some characters have bogus translations, but they are not used in French.
 //
@@ -458,7 +385,7 @@ FrenchVerbDictionary::readConjugation(xmlDocPtr doc, bool includeWithoutAccents)
                 continue;
 
             if (trace) cout << "readConjugation: mode node: '" << mode->name << "'" << endl;
-            Mode theMode = ::convertModeName(mode->name);
+            Mode theMode = FrenchVerbDictionary::convertModeName((char *) mode->name);
             ModeSpec &theModeSpec = theTemplateSpec[theMode];
 
             // For each tense in the mode:
@@ -469,7 +396,7 @@ FrenchVerbDictionary::readConjugation(xmlDocPtr doc, bool includeWithoutAccents)
                 if (equal(tense->name, "text") || equal(tense->name, "comment"))
                     continue;
 
-                Tense theTense = ::convertTenseName(tense->name);
+                Tense theTense = FrenchVerbDictionary::convertTenseName((char *) tense->name);
                 TenseSpec &theTenseSpec = theModeSpec[theTense];
 
                 // For each person in the tense:
@@ -530,10 +457,12 @@ string
 FrenchVerbDictionary::getUTF8XmlNodeText(xmlDocPtr doc, xmlNodePtr node)
                                                                 throw(int)
 {
-    xmlChar *s = getString(doc, node);
+    xmlChar *s = xmlNodeListGetString(doc, node, 1);
     if (s == NULL)
         return string();
-    return reinterpret_cast<char *>(s);
+    string result(reinterpret_cast<char *>(s));
+    xmlFree(s);
+    return result;
 }
 
 
@@ -541,10 +470,12 @@ string
 FrenchVerbDictionary::getUTF8XmlProp(xmlNodePtr node, const char *propName)
                                                                 throw(int)
 {
-    xmlChar *s = getProp(node, propName);
+    xmlChar *s = xmlGetProp(node, (const xmlChar *) propName);
     if (s == NULL)
         return string();
-    return reinterpret_cast<char *>(s);
+    string result(reinterpret_cast<char *>(s));
+    xmlFree(s);
+    return result;
 }
 
 
